# -*- coding: utf-8 -*-

# EeSSH -- SSH client for Eemyle
# By: Cyril Lacoux <clacoux@easter-eggs.com>
#
# Copyright (C) 2003-2019 Easter-eggs
# https://gitlab.easter-eggs.com/ee/eessh
#
# This file is part of EeSSH.
#
# EeSSH is free software; you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# EeSSH is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import logging
import os
log = logging.getLogger('eessh.cache')

CACHE_DIR = os.path.join(os.path.expanduser('~'), '.cache', 'eemyle') # XXX hard-coded path (and repeated elsewhere)

if not os.path.isdir(CACHE_DIR):
    log.warning("Creating directory {}".format(CACHE_DIR))
    os.makedirs(CACHE_DIR)

from dogpile.cache import make_region


def my_key_generator(namespace, fn, *args, **kwargs):
    _namespace = namespace or ""
    fname = fn.__qualname__
    def generate_key(*arg, **kw):
        res = ""
        if kw:
            res += "kwargs"
            for k, v in kw.items():
                res += "__{}::{}".format(str(k), str(v))
        return _namespace + "_" + fname + "_" + "_".join(str(s) for s in arg[1:]) + res
    return generate_key

xdgcache = make_region(
    function_key_generator = my_key_generator
).configure(
    'dogpile.cache.dbm',
    expiration_time = 3600 * 24 * 7,
    arguments = {
        "filename": CACHE_DIR + "/default",
    }
)